Learn R Programming

hugodown (version 0.0.0.9000)

create_site_academic: Create a hugo academic site

Description

Create a hugo academic 4.8.0 site, configured to work well with hugodown. In particular, it ensures that the following features important for R users work correctly:

  • Syntax highlighting (turns off default js highlighting, renables default chroma, and sets up styles in assets/chroma.css).

  • Math

  • HTML widgets

  • Default post archetype is tweaked to create .Rmd

Usage

create_site_academic(
  path = ".",
  open = is_interactive(),
  rstudio = rstudioapi::isAvailable()
)

Arguments

path

Path to create site

open

Open new site after creation?

rstudio

Create RStudio project?