Learn R Programming

hugodown (version 0.0.0.9000)

hugo_version: Find hugo version needed for current site

Description

Hugo changes rapidly, so it's important to pin your site to a specific version and then deliberately update when needed. This function reports which of hugo your site correctly uses.

The primary location of this information is the hugo_version field in hugodown.yaml. If that doesn't exist, we also look in netlify.toml.

Usage

hugo_version(site = ".")

Arguments

site

Path to hugo site.

See Also

hugo_install() to install any version of hugo.