Learn R Programming

hugodown (version 0.0.0.9000)

hugodown-package: hugodown: Make websites with hugo and RMarkdown

Description

logo

hugodown is a minimal version of blogdown that only supports hugo, and more clearly delineates the roles of RMarkdown (turning .Rmd into .md) and hugo (turning .md into .html).

Arguments

See Also

Useful links: