Learn R Programming

hugodown (version 0.0.0.9000)

site_outdated: Find .Rmds that need to be re-rendered.

Description

md_document() adds a hash of the input .Rmd in the YAML metdata of the .md file that it creates. This provides a reliable way to determine whether or not a .Rmd has been changed since the last time the .md was rendered.

Usage

site_outdated(site = ".")

Arguments

site

Path to hugo site.