Hugo changes rapidly, so it's important to pin your site to a specific
version and then deliberately update when needed. This function reports
which of hugo your site correctly uses.
The primary location of this information is the hugo_version field
in hugodown.yaml. If that doesn't exist, we also look in netlify.toml.